=========================================================
Cinder Configuration Documentation (source/configuration)
=========================================================

Introduction:
-------------

This directory is intended to hold any documentation that relates to
how to configure Cinder.  It is intended that some of this content
be automatically generated in the future.  At the moment, however, it
is not.  If you would like to work on this, please use Launchpad Bug
`#1847600 <https://bugs.launchpad.net/cinder/+bug/1847600>`_ for
tracking purposes.  Changes to configuration options for Cinder or its
drivers needs to be put under this directory.

The full spec for organization of documentation may be seen in the
`OS Manuals Migration Spec
<https://specs.openstack.org/openstack/docs-specs/specs/pike/os-manuals-migration.html>`_.

